==> seedsui-react-5.8.44.tgz: package/lib/Location/Main/index.js <==
var _excluded = ["ak", "autoLocation", "geocoder", "value", "onChange", "type", "markerConfig", "footerRender"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useEffect, useState } from 'react';
import Preview from "./Preview";
import Choose from "./Choose";
import Error from "./Error";

// 测试使用
// import { MapUtil } from 'seedsui-react'
// 内库使用
import MapUtil from "./../../MapUtil";

// 地图标注
var Main = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var ak = _ref.ak,
    _ref$autoLocation = _ref.autoLocation,
    autoLocation = _ref$autoLocation === void 0 ? true : _ref$autoLocation,
    geocoder = _ref.geocoder,
    value = _ref.value,
    onChange = _ref.onChange,
    type = _ref.type,
    markerConfig = _ref.markerConfig,
    footerRender = _ref.footerRender,
    props = _objectWithoutProperties(_ref, _excluded);
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    isLoaded = _useState2[0],
    setIsLoaded = _useState2[1];
  useEffect(function () {
    if (window.BMap) {
      setIsLoaded(true);
      return;
    }
    if (ak) {
      MapUtil.load({
        ak: ak,
        success: function success() {
          setIsLoaded(true);
        },
        fail: function fail() {
          setIsLoaded('地图库加载失败，请稍后再试！');
        }
      });
    } else {
      setIsLoaded('未加载地图库，请传入ak！');
    }
    // eslint-disable-next-line
  }, []);
  if (isLoaded === true && type === 'preview') {
    return /*#__PURE__*/React.createElement(Preview, _extends({
      ref: ref,
      markerConfig: markerConfig,
      value: value,
      footerRender: footerRender
    }, props));
  }
  if (isLoaded === true && type === 'choose') {
    return /*#__PURE__*/React.createElement(Choose, _extends({
      ref: ref,
      markerConfig: markerConfig,
      autoLocation: autoLocation,
      value: value,
      onChange: onChange,
      geocoder: geocoder,
      footerRender: footerRender
    }, props));
  }
  if (typeof isLoaded === 'string') {
    return /*#__PURE__*/React.createElement(Error, _extends({
      ref: ref,
      errMsg: isLoaded
    }, props));
  }
  return null;
});
export default Main;

==> seedsui-react-5.8.81.tgz: package/lib/Location/Main/index.js <==
var _excluded = ["visible", "config", "type", "autoLocation", "getLocation", "getAddress", "value", "onChange", "footerRender"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef } from 'react';
import _ from 'lodash';
import Preview from "./Preview";
import Choose from "./Choose";

// 内库使用
import Map from "./../../Map";

// 测试使用
// import { Map } from 'seedsui-react'

var coordsToWgs84 = Map.coordsToWgs84,
  wgs84ToCoords = Map.wgs84ToCoords;

// 地图标注
var Main = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var visible = _ref.visible,
    config = _ref.config,
    type = _ref.type,
    _ref$autoLocation = _ref.autoLocation,
    autoLocation = _ref$autoLocation === void 0 ? true : _ref$autoLocation,
    getLocation = _ref.getLocation,
    getAddress = _ref.getAddress,
    value = _ref.value,
    _onChange = _ref.onChange,
    footerRender = _ref.footerRender,
    props = _objectWithoutProperties(_ref, _excluded);
  if (!_.isEmpty(value)) {
    // eslint-disable-next-line
    value = coordsToWgs84(value, type);
  }
  if (visible === 'preview') {
    return /*#__PURE__*/React.createElement(Preview, _extends({
      ref: ref,
      config: config,
      value: value
    }, props));
  }
  if (visible === 'choose') {
    return /*#__PURE__*/React.createElement(Choose, _extends({
      ref: ref,
      config: config,
      autoLocation: autoLocation,
      getLocation: getLocation,
      getAddress: getAddress,
      value: value,
      onChange: function onChange(newValue) {
        if (!_.isEmpty(newValue)) {
          // eslint-disable-next-line
          newValue = wgs84ToCoords(newValue, type);
        }
        _onChange && _onChange(newValue);
      }
    }, props));
  }
  return null;
});
export default Main;
